Learn R Programming

cosinor (version 1.0)

predict.cosinor.lm: Predict from a cosinor model

Description

Given a time variable and optional covariates, generate predicted values from a cosinor fit. Default prediction is the mean value, optionally can predict at a given month

Usage

## S3 method for class 'cosinor.lm':
predict(object, newdata, ...)

Arguments

object
An object of class cosinor.lm
newdata
Optional new data
...
other arguments

Examples

Run this code
fit <- cosinor.lm(Y ~ time(time) + X + amp.acro(X), data = vitamind)
predict(fit)

Run the code above in your browser using DataLab