Learn R Programming

cosinor (version 1.0)

simulate_cosinor: Simulate data from a cosinor model

Description

This function simulates data from a cosinor model with a single covariate, where the time scale is month, and optionally allows for single covariate effects on the mean, amplitude, and acrophase.

Usage

simulate_cosinor(n, beta.mean = 2, beta.amp = 0, beta.acro = 0)

Arguments

n
Sample size
beta.mean
Effect on the mean (intercept)
beta.amp
Effect on the amplitude
beta.acro
Effect on the acrophase