Learn R Programming

cosinor (version 1.0)

vitamind: Vitamin D

Description

Simulated data set to illustrate the cosinor model. Y is an outcome variable that varies of time time according to a cosine curve. The binary covariate X is associated with the mean and amplitude of the cosine curve.

Usage

vitamind

Arguments

format

A data frame with 3 variables: X, Y, time.